<?php

namespace Drupal\style_selector\Plugin\Field\FieldType;

use Drupal\options\Plugin\Field\FieldType\ListStringItem;
use Drupal\Core\StringTranslation\StringTranslationTrait;

/**
 * Plugin implementation of the 'style_selector_css_class' field type.
 *
 * @FieldType(
 *   id = "style_selector_css_class",
 *   label = @Translation("Style list"),
 *   description = @Translation("This field stores CSS Class values from a list of allowed 'value => label' pairs, i.e. 'Styles': bgstyle--red => Red, bgstyle--white => White, bgstyle--blue => Blue."),
 *   category = @Translation("Style Selector"),
 *   default_widget = "style_selector_css_class_widget",
 *   default_formatter = "style_selector_css_class_formatter",
 *   cardinality = 1,
 * )
 */
class CssClassItem extends ListStringItem {
  use StringTranslationTrait;

  /**
   * {@inheritdoc}
   */
  protected function allowedValuesDescription() {
    $description = '<p>' . $this->t('The possible values this field can contain. Enter one value per line, in the format key|label.');
    $description .= '<br/>' . $this->t('The key is the stored value, and can be any valid CSS class identifier.');
    $description .= '<br/>' . $this->t('The label will be used in displayed values and edit forms. Both key and label are required.');
    $description .= '</p>';

    return $description;
  }

}
