<?php

namespace Drupal\style_selector\Plugin\Field\FieldType;

use Drupal\options\Plugin\Field\FieldType\ListStringItem;
use Drupal\Core\StringTranslation\StringTranslationTrait;

/**
 * Plugin implementation of the 'style_selector_css_color' field type.
 *
 * @FieldType(
 *   id = "style_selector_css_color",
 *   label = @Translation("Color list"),
 *   description = @Translation("This field stores CSS Color values from a list of allowed 'value => label' pairs, i.e. 'Styles': red => Red, rgb(255,255,255) => White, #0000FF => Blue."),
 *   category = @Translation("Style Selector"),
 *   default_widget = "style_selector_css_color_widget",
 *   default_formatter = "style_selector_css_color_formatter",
 *   cardinality = 1,
 * )
 */
class CssColorItem extends ListStringItem {
  use StringTranslationTrait;

  /**
   * {@inheritdoc}
   */
  protected function allowedValuesDescription() {
    $description = '<p>' . $this->t('The possible values this field can contain. Enter one value per line, in the format key|label.');
    $description .= '<br/>' . $this->t('The key is the stored value, and must be a valid, supported CSS color format.');
    $description .= ' <strong>' . $this->t('Hex values must be prefixed with #, and will be converted and stored as RGB.') . '</strong>';
    $description .= '<br/>' . $this->t('The label will be used in displayed values and edit forms. Both key and label are required.');
    $description .= '</p>';
    return $description;
  }

  /**
   * {@inheritdoc}
   */
  protected static function validateAllowedValue($option) {
    parent::validateAllowedValue($option);
    if (!\Drupal::service('style_selector.css_color')->getFormSafeColorValue($option)) {
      return t('Option @opt is not a valid CSS color.', [
        '@opt' => $option,
      ]);
    }
  }

  /**
   * {@inheritdoc}
   */
  protected static function castAllowedValue($value) {
    // Convert hex values are converted to rgb.
    return (string) \Drupal::service('style_selector.css_color')->getFormSafeColorValue($value);
  }

}
