<?php

namespace Drupal\style_selector\Plugin\Field\FieldWidget;

use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Field\Plugin\Field\FieldWidget\OptionsWidgetBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Base class for Style Selector widgets.
 */
abstract class SelectorWidgetBase extends OptionsWidgetBase {

  /**
   * {@inheritdoc}
   */
  public function formElement(FieldItemListInterface $items, $delta, array $element, array &$form, FormStateInterface $form_state) {
    $element = parent::formElement($items, $delta, $element, $form, $form_state);

    $options = $this->getOptions($items->getEntity());
    $selected = $this->getSelectedOptions($items);

    $element += [
      '#type' => 'style_selector',
      '#options' => $options,
      '#default_value' => $selected ? reset($selected) : NULL,
      '#ui_style' => $this->getSetting('ui_style'),
      '#required' => $this->fieldDefinition->isRequired(),
    ];

    foreach ($element['#options'] as $key => $label) {
      $element['#styles'][$key] = $label;
    }

    return $element;
  }

  /**
   * {@inheritdoc}
   */
  public static function defaultSettings() {
    return [
      'ui_style' => 'round',
    ] + parent::defaultSettings();
  }

  /**
   * {@inheritdoc}
   */
  public function settingsForm(array $form, FormStateInterface $form_state) {
    $element['ui_style'] = [
      '#type' => 'select',
      '#title' => $this->t('Field UI Style'),
      '#options' => [
        'round' => $this->t('Round'),
        'round-large' => $this->t('Round - Large'),
        'rect' => $this->t('Rectangle'),
        'rect-large' => $this->t('Rectangle - Large'),
      ],
      '#default_value' => $this->getSetting('ui_style'),
      '#required' => TRUE,
    ];

    return $element;
  }

  /**
   * {@inheritdoc}
   */
  public function settingsSummary() {
    $summary = [];
    $summary[] = $this->t('UI style: @ui_style', ['@ui_style' => $this->getSetting('ui_style')]);

    return $summary;
  }

}
